@@ -40,7 +40,7 @@ class Todo {
 
 		// this is saved
 		Priority priority;
-		string text;
+		string text, comment;
 		bool done;
 		time_t added, doneTime;
 
