@@ -30,6 +30,7 @@ void TodoDB::initColour() {
 	streamColour["verylow"] = StreamColour(blue, bold);
 	streamColour["info"] = StreamColour(green, StreamColour::mono);
 	streamColour["title"] = StreamColour(green, bold);
+	streamColour["comment"] = StreamColour(white, bold);
 }
 
 void TodoDB::initColourPost() {
@@ -41,6 +42,7 @@ void TodoDB::initColourPost() {
 		streamColour["verylow"] = StreamColour(StreamColour::mono, StreamColour::mono);
 		streamColour["info"] = StreamColour(StreamColour::mono, StreamColour::mono);
 		streamColour["title"] = StreamColour(StreamColour::mono, StreamColour::mono);
+		streamColour["comment"] = StreamColour(StreamColour::mono, StreamColour::mono);
 		priority[0] = StreamColour::mono;
 		priority[1] = StreamColour::mono;
 		priority[2] = StreamColour::mono;
@@ -49,6 +51,7 @@ void TodoDB::initColourPost() {
 		info = StreamColour::mono;
 		title = StreamColour::mono;
 		normal = StreamColour::mono;
+		comment = StreamColour::mono;
 	} else {
 		priority[0] = StreamColour::veryhigh;
 		priority[1] = StreamColour::high;
@@ -58,6 +61,7 @@ void TodoDB::initColourPost() {
 		info = StreamColour::info;
 		title = StreamColour::title;
 		normal = StreamColour::normal;
+		comment = StreamColour::comment;
 	}
 
 }
@@ -280,6 +284,12 @@ void TodoDB::save(multiset<Todo> const &todo, ostream &of, int ind) {
 		of << ">" << endl;
 		of << string((ind + 1) * 4, ' ');
 		of << htmlify((*i).text) << endl;
+		if ((*i).comment != "") {
+			of << "<comment>" << endl;
+			of << string((ind + 2) * 4, ' ');
+			of << htmlify((*i).comment) << endl;
+			of << "</comment>" << endl;
+		}
 		save((*i).child, of, ind + 1);
 		of << string(ind * 4, ' ');
 		of << "</note>" << endl;
@@ -440,7 +450,7 @@ vector<string> tmp = split(",", str), out;
 	This function allows for tab completion of priority levels as well
 	as the levels being in the command history.
 */
-Todo::Priority TodoDB::getPriority(string current = "")
+Todo::Priority TodoDB::getPriority(string current)
 {
 char *pri[] = {
 	"veryhigh",
@@ -569,6 +579,12 @@ Todo t = *find(todo, index);
 		t.priority = options.priority;
 	t.priority = getPriority(symbolisePriority(t.priority));
 
+	if (options.comment || t.comment != "") {
+		if (options.verbose)
+			cout << info << "Enter comment for this item." << normal << endl;
+		t.comment = readText("comment> ", t.comment);
+	}
+
 	if (index.find(".") != string::npos) {
 string parent = index.substr(0, index.rfind("."));
 
@@ -703,11 +719,25 @@ void TodoDB::view(multiset<Todo> const &todo, int ind) {
 	for (multiset<Todo>::iterator i = todo.begin(); i != todo.end(); i++) {
 	Todo const &todo = (*i);
 
-		if (!todo.filtered)
+		if (!todo.filtered) {
 			if (options.verbose)
 				formatItem(cout, ind, todo, options.format["verbose-display"]);
 			else
 				formatItem(cout, ind, todo, options.format["display"]);
+			if (options.comment && todo.comment != "") {
+			int indent = 4 * (ind + 1);
+
+				cout << comment << string(indent, ' ');
+				if (options.summary) {
+					if ((int)todo.comment.size() > options.columns - 3 - indent)
+						cout << "(" << todo.comment.substr(0, options.columns - 3 - indent) << ")" << info << "+";
+					else
+						cout << "(" << todo.comment << ")";
+				} else
+					wraptext(cout, "(" + todo.comment + ")", indent, indent, options.columns);
+				cout << normal << endl;
+			}
+		}
 
 		//if (todo.filterchildren && !todo.unfilteredchildren) continue;
 		if (todo.filtered && todo.unfilteredchildren)
@@ -720,7 +750,7 @@ void TodoDB::view() {
 	if (titleText != "") {
 		cout << title;
 		wraptext(cout, titleText, 4, 0, options.columns - 8);
-		cout << normal;
+		cout << endl << normal;
 	}
 	filterView();
 	if (options.verbose > 1)
@@ -792,6 +822,9 @@ int marked = 0;
 			if (options.verbose > 1)
 				cout << "todo: marked '" << *j << "' as done" << endl;
 			t->doneTime = getCurrentDate();
+			if (options.verbose)
+				cout << info << "Enter comment for this item." << normal << endl;
+			t->comment = readText("comment> ", t->comment);
 		} else
 			notfound.push_back(*j);
 	}
@@ -828,6 +861,7 @@ void TodoDB::setColour(string const &item, string const &colour) {
 ostream &(*c)(ostream &);
 ostream &(*a)(ostream &) = StreamColour::mono;
 string clr = colour;
+
 	if (clr[0] == '+') {
 		a = ::bold;
 		clr = colour.substr(1);
@@ -887,6 +921,7 @@ ostream &TodoDB::StreamColour::low(ostream &os) { return os << normal << streamC
 ostream &TodoDB::StreamColour::verylow(ostream &os) { return os << normal << streamColour["verylow"].attribute << streamColour["verylow"].colour; }
 ostream &TodoDB::StreamColour::info(ostream &os) { return os << normal << streamColour["info"].attribute << streamColour["info"].colour; }
 ostream &TodoDB::StreamColour::title(ostream &os) { return os << normal << streamColour["title"].attribute << streamColour["title"].colour; }
+ostream &TodoDB::StreamColour::comment(ostream &os) { return os << normal << streamColour["comment"].attribute << streamColour["comment"].colour; }
 ostream &TodoDB::StreamColour::mono(ostream &os) { return os; }
 ostream &TodoDB::StreamColour::normal(ostream &os) { return os << ::normal; }
 
@@ -967,12 +1002,11 @@ Options::Dir dir = Options::Equal;
 						i *= defaultindent;
 						if (options.summary) {
 							if ((int)item.text.size() > options.columns - 1 - indent)
-								out << item.text.substr(0, options.columns - 1 - indent) << info << "+" << normal << endl;
+								out << item.text.substr(0, options.columns - 1 - indent) << info << "+" << normal;
 							else
-								out << item.text << endl;
+								out << item.text;
 						} else
 							wraptext(out, item.text, i, indent, options.columns);
-						indent = 0;
 					}
 					break;
 					case 't' :
@@ -1096,6 +1130,9 @@ Options::Dir dir = Options::Equal;
 						else
 						if (colour == "normal")
 							out << normal;
+						else
+						if (colour == "comment")
+							out << comment;
 						else
 							out << priority[4 - desymbolisePriority(colour)];
 					}
