@@ -19,7 +19,7 @@ Options options;
 
 Options::Options() :
 	verbose(0), mono(false), paranoid(false), global(false),
-	summary(false), timeout(false),
+	summary(false), timeout(false), comment(false),
 	database(".todo"),
 	priority(Todo::None),
 	mode(TodoDB::View),
@@ -27,10 +27,11 @@ Options::Options() :
 
 	// default formatting strings
 	format["date"] = "%c";
-	format["display"] = "%4>%i%f%[info]%2n.%[priority]%+1T";
-	format["verbose-display"] = "%i%[info]%f%2n.%[priority]%+1T%+1i%[info]Added: %[normal]%c  %[info]Completed: %[normal]%d\n%+1i%[info]Duration: %[normal]%D  %[info]Priority: %[normal]%p\n\n";
-	format["generated"] = "%2>%i-%+1T%+1i(added %c, completed %d, priority %p)\n\n";
-	format["verbose-generated"] = "%2>%i- %+1T\n%+1iAdded: %c  Completed: %d\n%+1iDuration: %D  Priority: %p\n\n\n";
+	format["display"] = "%4>%i%f%[info]%2n.%[priority]%+1T\n";
+	format["comment-display"] = "%4>%i%f%[info]%2n.%[priority]%+1T\n%+1i%[comment](Comment: %C)\n";
+	format["verbose-display"] = "%i%[info]%f%2n.%[priority]%+1T\n%+1i%[info]Added: %[normal]%c  %[info]Completed: %[normal]%d\n%+1i%[info]Duration: %[normal]%D  %[info]Priority: %[normal]%p\n\n";
+	format["generated"] = "%2>%i-%+1T\n%+1i(added %c, completed %d, priority %p)\n\n";
+	format["verbose-generated"] = "%2>%i- %+1T\n\n%+1iAdded: %c  Completed: %d\n%+1iDuration: %D  Priority: %p\n\n\n";
 
 	loaders.push_back("xml");
 	loaders.push_back("binary");
@@ -210,6 +211,8 @@ enum { Help = -100, Remove, Version, Title, Colour, Mono,
 	args.setHelp(Remove, "Remove the note that is indexed by the given number.");
 	args.addArgument('d', "done", CommandArgs::Required);
 	args.setHelp('d', "Mark the specified notes (and all children) as done.");
+	args.addArgument('c', "comment");
+	args.setHelp('c', "Also manipulate finishing comment for item when viewing or marking as done.");
 	args.addArgument('D', "not-done", CommandArgs::Required);
 	args.setHelp('D', "Mark the specified notes (and all children) as not done.");
 	args.addArgument(GlobalDatabase, "global-database", CommandArgs::Required);
@@ -353,10 +356,13 @@ enum { Help = -100, Remove, Version, Title, Colour, Mono,
 			}
 			break;
 			case Format : {
-			vector<string> comp = str::split("=", i.parameter());
-
-				if (comp.size() != 2)
+			vector<string> comp;
+			
+				if (!strchr(i.parameter(), '='))
 					throw runtime_error("invalid usage of --format");
+			string tmp = i.parameter();
+				comp.push_back(tmp.substr(0, strchr(i.parameter(), '=') - i.parameter()));
+				comp.push_back(tmp.substr(strchr(i.parameter(), '=') - i.parameter() + 1));
 				options.format[comp[0]] = comp[1];
 			}
 			break;
@@ -513,6 +519,9 @@ enum { Help = -100, Remove, Version, Title, Colour, Mono,
 				options.index = todo.getIndexList(i.parameter());
 				options.mode = TodoDB::Remove;
 			break;
+			case 'c' :
+				options.comment = true;
+			break;
 			case 'd' : 
 				options.index = todo.getIndexList(i.parameter());
 				options.mode = TodoDB::Done;
@@ -730,7 +739,7 @@ static bool rcvalid(string const &str) {
 		str == "summary" || str == "timeoutseconds" ||
 		str == "timeout" || str == "format" ||
 		str == "use-format" || str == "paranoid" || str == "exec" || 
-		str == "echo";
+		str == "echo" || str == "comment";
 }
 
 /*
@@ -838,8 +847,10 @@ vector<string> rcfile, out;
 
 string expandEnvars(string const &str) {
 string out;
+string envar = "TODODB=" + options.database;
 
-	setenv("TODODB", options.database.c_str(), 1);
+	//setenv("TODODB", options.database.c_str(), 1);
+	putenv(const_cast<char*>(envar.c_str()));
 
 	for (unsigned i = 0; i < str.size(); ++i)
 		if (str[i] == '$') {
